@@ -1,10 +1,12 @@
 import numpy as np
 import pandas as pd
+
 from metaDMG.errors import MismatchFileError
 
 #
 from metaDMG.fit import fit_utils
 
+
 columns = [
     "tax_id",
     "direction",
@@ -38,6 +40,10 @@ def get_base_columns(df):
     return base_columns
 
 
+def rename_columns(df):
+    return df.rename(columns={"#taxid": "tax_id", "#taxidStr": "tax_id"})
+
+
 def select_read_directions(df, config):
     if config["forward_only"]:
         return fit_utils.get_forward(df)
@@ -178,8 +184,8 @@ def add_k_N_x_names(df, config):
     return df
 
 
-def rename_columns(df):
-    return df.rename(columns={"#taxid": "tax_id"})
+def make_tax_id_str(df):
+    return df.astype({"tax_id": "str"})
 
 
 def csv_contains_less_than_N_lines(filename, N=2):
@@ -214,6 +220,7 @@ def compute(config):
         .pipe(add_k_N_x_names, config)
         .pipe(add_k_sum_counts)
         .pipe(add_min_N_in_group, config)
+        .pipe(make_tax_id_str)
         # .pipe(filter_cut_based_on_cfg, cfg)
         .reset_index(drop=True)
         .fillna(0)
@@ -221,6 +228,7 @@ def compute(config):
 
     df["sample"] = config["sample"]
     categories = ["tax_id", "direction", "sample"]
+
     df_mismatches = fit_utils.downcast_dataframe(df, categories, fully_automatic=False)
 
     return df_mismatches
