@@ -1,10 +1,12 @@
 #%%
+import warnings
 from collections import defaultdict
+
 import numpy as np
 import pandas as pd
 from logger_tt import logger
 from scipy.stats import betabinom as sp_betabinom
-import warnings
+
 
 #%%
 
@@ -149,67 +151,3 @@ def get_database_read_ids(config):
 
 
 #%%
-
-
-def get_single_fit_prediction(df_results):
-
-    Bayesian = any(["Bayesian" in column for column in df_results.columns])
-
-    if Bayesian:
-        prefix = "Bayesian_"
-    else:
-        prefix = ""
-
-    A = df_results[f"{prefix}A"].values
-    q = df_results[f"{prefix}q"].values
-    c = df_results[f"{prefix}c"].values
-    phi = df_results[f"{prefix}phi"].values
-
-    max_position = max(
-        [
-            int(name.split("+")[1])
-            for name in df_results.columns
-            if name.startswith("k+")
-        ]
-    )
-
-    x = np.hstack(
-        [np.arange(max_position) + 1, np.arange(-1, -max_position - 1, -1)]
-    ).reshape((-1, 1))
-
-    mask_N = [
-        (name.startswith("N+") or name.startswith("N-")) for name in df_results.columns
-    ]
-    N = df_results.iloc[:, mask_N].values
-
-    Dx = A * (1 - q) ** (np.abs(x) - 1) + c
-
-    alpha = Dx * phi
-    beta = (1 - Dx) * phi
-
-    dist = sp_betabinom(n=N, a=alpha.T, b=beta.T)
-
-    with warnings.catch_warnings():
-        warnings.filterwarnings("ignore")
-        std = dist.std() / N
-
-    std[np.isnan(std)] = 0
-
-    df_Dx = pd.concat(
-        (
-            # pd.DataFrame(df_results.tax_id, columns=["tax_id"]),
-            pd.DataFrame(Dx.T, columns=[f"Dx{xi:+}" for xi in x.flatten()]),
-            pd.DataFrame(std, columns=[f"Dx_std{xi:+}" for xi in x.flatten()]),
-        ),
-        axis=1,
-    )
-
-    return df_Dx
-
-
-def append_fit_predictions(df_results):
-    df_Dx = get_single_fit_prediction(df_results)
-    return pd.concat((df_results.reset_index(drop=True), df_Dx), axis=1)
-
-
-# %%
